@@ -4,7 +4,7 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '0.0.4';
+our $VERSION = '0.0.5';
 our $ENABLE_DEBUG = 0;
 
 require XSLoader;
@@ -19,7 +19,7 @@ AVLTree - Perl extension for efficient creation and manipulation of AVL balanced
 
 =head1 VERSION
 
-Version 0.0.4
+Version 0.0.5
 
 =head1 DESCRIPTION
 
@@ -205,6 +205,9 @@ and List::Util modules.
 
 =head1 CHANGES
 
+0.0.5 Sat 30 Dec 2017
+   * Attempt to circumnvent compilation problems with threaded versions
+
 0.0,4 Sun 24 Dec 2017
    * Minor improvements in the documentation
 
